pyparsing.pyparsing._NullToken

Package pyparsing :: Module pyparsing :: Class _NullToken |
[hide private]
[frames] | no frames]

# Class _NullToken

source code

    object --+
             |
            _NullToken

Instance Methods | [hide private]
__bool__(self) | source code
__nonzero__(self) | source code
__str__(self) str(x) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)